/**
 * DSS - Digital Signature Services
 * Copyright (C) 2015 European Commission, provided under the CEF programme
 *
 * This file is part of the "DSS - Digital Signature Services" project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package eu.europa.esig.dss.pades;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.IOException;
import java.util.List;

import org.junit.Test;

import eu.europa.esig.dss.DSSDocument;
import eu.europa.esig.dss.DSSException;
import eu.europa.esig.dss.FileDocument;
import eu.europa.esig.dss.pades.signature.PAdESService;
import eu.europa.esig.dss.utils.Utils;
import eu.europa.esig.dss.validation.CommonCertificateVerifier;

public class PAdESServiceTest {

	private PAdESService padesService = new PAdESService(new CommonCertificateVerifier());

	@Test
	public void testGetSignatureFields() {
		assertTrue(Utils.isCollectionNotEmpty(padesService.getAvailableSignatureFields(new FileDocument("src/test/resources/doc.pdf"))));
	}

	@Test
	public void testAddSignatureField() throws IOException {
		FileDocument document = new FileDocument("src/test/resources/sample.pdf");
		assertTrue(Utils.isCollectionEmpty(padesService.getAvailableSignatureFields(document)));

		SignatureFieldParameters parameters = new SignatureFieldParameters();
		parameters.setPage(0);
		parameters.setName("signature-test");
		parameters.setOriginX(50);
		parameters.setOriginY(50);
		parameters.setWidth(200);
		parameters.setHeight(200);

		DSSDocument newDocument = padesService.addNewSignatureField(document, parameters);
		// newDocument.save("target/new-pdf.pdf");

		List<String> availableSignatureFields = padesService.getAvailableSignatureFields(newDocument);
		assertTrue(availableSignatureFields.contains("signature-test"));

		parameters = new SignatureFieldParameters();
		parameters.setPage(0);
		parameters.setName("signature-test2");
		parameters.setOriginX(100);
		parameters.setOriginY(100);
		parameters.setWidth(50);
		parameters.setHeight(50);

		DSSDocument newDocument2 = padesService.addNewSignatureField(newDocument, parameters);
		availableSignatureFields = padesService.getAvailableSignatureFields(newDocument2);
		assertEquals(2, availableSignatureFields.size());
	}

	@Test(expected = DSSException.class)
	public void testAddSignatureFieldPageNotFound() throws IOException {
		FileDocument document = new FileDocument("src/test/resources/sample.pdf");
		assertTrue(Utils.isCollectionEmpty(padesService.getAvailableSignatureFields(document)));

		SignatureFieldParameters parameters = new SignatureFieldParameters();
		parameters.setPage(10);
		parameters.setName("signature-test");
		parameters.setOriginX(50);
		parameters.setOriginY(50);
		parameters.setWidth(200);
		parameters.setHeight(200);

		padesService.addNewSignatureField(document, parameters);
	}

}
